==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>找不到結果</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>確定移除 %1？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>移除桌面捷徑</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>移除 Dock 捷徑</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation>開啟時套用 Proxy</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>停用畫面縮放</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開放</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>建立桌面捷徑</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>釘選到 Dock</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>取消開機啟動</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>開機啟動</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>網路</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>聊天</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>圖形</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>遊戲</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>辦公</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>閱讀</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>開發</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系統</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>其他</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>確定移除 %1？</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>所有依賴的軟體也會移除</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>電腦</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>登出</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>電腦</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>登出</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下載</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>電腦</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手冊</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>確定移除 %1？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
</context>
</TS>

==> dde-launcher_5.0.14.orig.tar.xz: dde-launcher-5.0.14/translations/dde-launcher_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>找不到結果</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>網路</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>聊天</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>圖形</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>辦公</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>閱讀</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>開發</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系統</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>遊戲娛樂</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其它</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>確定解除安裝 %1？</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>移除桌面捷徑</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>移除 Dock 捷徑</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>停用畫面縮放</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開放</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>建立桌面捷徑</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>釘選到 Dock</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>取消開機啟動</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>開機啟動</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation>使用代理伺服器</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>所有應用程式</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>網路</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>聊天</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>圖形</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>遊戲</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>辦公</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>閱讀</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>開發</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系統</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>其他</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>電腦</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>登出</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>電腦</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>登出</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下載</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>電腦</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>手冊</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>所有分類</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>確定</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>確定解除安裝 %1？</translation>
    </message>
</context>
</TS>
